@@ -26,7 +26,7 @@ use warnings;
 use List::Util ();
 use Padre::Wx  ();
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 use constant GOLDEN_RATIO => 1.618;
 
@@ -175,7 +175,7 @@ sub _rect_golden {
 	if ( $rect->width > ( $rect->height * GOLDEN_RATIO ) ) {
 
 		# Shrink left from the right
-		$rect->width( int( $rect->height / GOLDEN_RATIO ) );
+		$rect->width( int( $rect->height * GOLDEN_RATIO ) );
 	} else {
 
 		# Shrink up from the bottom
